#!/usr/bin/env python

""""""
# AUSnumtools - A lightweight Python module that validates Australian phone numbers."""

# SPDX-FileCopyrightText: 2025 Ben Bonacci <ben at benbonaccci dot com>
# SPDX-License-Identifier: GPL-3.0-only

""""""
import re


AUS_NUM_ANY_REGEX = re.compile("^[0][2|3|4|7|8][0-9]{8}$")
AUS_NUM_LANDLINE_REGEX = re.compile("^[0][2|3|7|8][0-9]{8}$")
AUS_NUM_MOBILE_REGEX = re.compile("^[0][4][0-9]{8}$")


## Default preferences
#None


## Functions
def is_au_landline(number: str) -> bool:
    """Validates that the provided phone number is valid for an Australian landline"""
    if AUS_NUM_LANDLINE_REGEX.search(number):
        return True
    else:
        return False

def is_au_mobile(number: str) -> bool:
    """Validates that the provided phone number is valid for an Australian mobile"""
    if AUS_NUM_MOBILE_REGEX.search(number):
        return True
    else:
        return False

def is_au_number(number: str) -> bool:
    """Validates that the provided phone number is valid for an Australian landline or an Australian mobile"""
    if AUS_NUM_ANY_REGEX.search(number):
        return True
    else:
        return False



if __name__ == "__main__":
    print("AUSnumtools is a Python module and not an interactive Python script. Please import AUSnumtools in order to use it. Consult the documentation for further assistance.")
